@@ -2,7 +2,7 @@
 asyncapi
 """
 
-__version__ = '0.7.2'
+__version__ = '0.8.0'
 from .api import AsyncApi, OperationsTypeHint
 from .builder import (
     build_api,
@@ -12,17 +12,6 @@ from .builder import (
     dict_from_ref,
     fill_refs,
 )
-from .entities import (
-    Channel,
-    Components,
-    Info,
-    Message,
-    ProtocolType,
-    Server,
-    Spec,
-    Specification,
-    Subscribe,
-)
 from .exceptions import (
     ChannelOperationNotFoundError,
     InvalidChannelError,
@@ -30,6 +19,17 @@ from .exceptions import (
     ReferenceNotFoundError,
     UrlOrModuleRequiredError,
 )
+from .specification_v2_0_0 import (
+    AutoSpec,
+    Channel,
+    Components,
+    Info,
+    Message,
+    Operation,
+    ProtocolType,
+    Server,
+    Specification,
+)
 from .subscriber import run as run_subscriber
 
 
@@ -44,8 +44,8 @@ __all__ = [
     'ProtocolType',
     'Server',
     'Specification',
-    'Subscribe',
-    'Spec',
+    'Operation',
+    'AutoSpec',
     'AsyncApi',
     'OperationsTypeHint',
     'build_api',
